====================
Administrator Guide
====================

This guide provides information for deploying, configuring, and operating
networking-baremetal in production environments.

.. toctree::
   :maxdepth: 2

   HA Chassis Group Alignment <ha-chassis-group-alignment>
   L2VNI Trunk Reconciliation <l2vni-trunk-reconciliation>
